# Awlsim - Quick start tutorial


Start the GUI by invoking `awlsim-gui` on Linux, `awlsim-win.cmd` on Windows or `awlsim.cmd` on Windows (Awlsim standalone package). The following screen will appear:

<a href="doc/pic/quick-start/awlsim-gui-000.png"><img src="doc/pic/quick-start/awlsim-gui-000.png" width="600" alt="awlsim-gui" /></a>

Enter the AWL/STL program in the editor area:

<a href="doc/pic/quick-start/awlsim-gui-001.png"><img src="doc/pic/quick-start/awlsim-gui-001.png" width="600" alt="awlsim-gui" /></a>

Press the `download all sources` button. If you did not do this before, the `connect dialog` will appear. Just select a `simulator core` and click `Accept`.

You will need to download the sources again, if you edit the sources later. But the `connect dialog` will not appear again.

<a href="doc/pic/quick-start/awlsim-gui-002.png"><img src="doc/pic/quick-start/awlsim-gui-002.png" width="600" alt="awlsim-gui" /></a>

Press the `RUN` button to start the simulated CPU:

<a href="doc/pic/quick-start/awlsim-gui-003.png"><img src="doc/pic/quick-start/awlsim-gui-003.png" width="600" alt="awlsim-gui" /></a>

You may want to open some inspection windows to see the program output or manually set some program input:

<a href="doc/pic/quick-start/awlsim-gui-004.png"><img src="doc/pic/quick-start/awlsim-gui-004.png" width="600" alt="awlsim-gui" /></a>
